@@ -53,6 +53,13 @@ sub dump {
     my $workdir = "$self->{workdir}/$self->{month}/$self->{date}";
     make_path($workdir) unless -d $workdir;
 
+    my $enc = Encode::Guess->guess($text);
+    ref($enc) or croak "无法猜测编码: $enc";
+    eval { $text = $enc->decode($text); };
+    if (!!$@) {
+      warn("字符串($text)解码失败：$@") if $self->debug == 0;
+    }
+
     my $filename = "$workdir/$self->{device}{host}.txt";
     open(my $fh, '>>:encoding(UTF-8)', $filename) or croak "无法打开文件 $filename 进行写入: $!";
     print $fh "$text\n"                           or croak "写入文件 $filename 失败: $!";
@@ -69,7 +76,14 @@ sub write_file {
   my $workdir = "$self->{workdir}/$self->{month}/$self->{date}";
   make_path($workdir) unless -d $workdir;
 
+  my $enc = Encode::Guess->guess($config);
+  ref($enc) or croak "无法猜测编码: $enc";
+  eval { $config = $enc->decode($config); };
+  if (!!$@) {
+    warn("字符串($config)解码失败：$@") if $self->debug == 0;
+  }
   $self->dump("准备将配置文件写入工作目录: ($workdir)");
+
   my $filename = "$workdir/$name";
   open(my $fh, '>>encoding(UTF-8)', $filename) or croak "无法打开文件 $filename 进行写入: $!";
   print $fh $config                            or croak "写入文件 $filename 失败: $!";
